@@ -1,28 +1,18 @@
-## @file
-# Status process mechanism
-
 package Lemonldap::NG::Handler::Status;
 
 use strict;
 use POSIX;
 use Data::Dumper;
 
-#inherits Cache::Cache
-
-our $VERSION = '0.99.1';
+our $VERSION  = "0.2";
 
 our $status   = {};
 our $activity = [];
 our $start    = int( time / 60 );
 use constant MN_COUNT => 5;
 
-our $page_title = 'Lemonldap::NG statistics';
-
-## @fn private hashRef portalTab()
-# @return Constant hash used to convert error codes into string.
 sub portalTab {
     return {
-        -3 => 'PE_INFO',
         -2 => 'PORTAL_REDIRECT',
         -1 => 'PORTAL_ALREADY_AUTHENTICATED',
         0  => 'PORTAL_OK',
@@ -36,33 +26,18 @@ sub portalTab {
         8  => 'PORTAL_APACHESESSIONERROR',
         9  => 'PORTAL_FIRSTACCESS',
         10 => 'PORTAL_BADCERTIFICATE',
+        11 => 'PORTAL_LA_FAILED',
+        12 => 'PORTAL_LA_ARTFAILED',
+        13 => 'PORTAL_LA_DEFEDFAILED',
+        14 => 'PORTAL_LA_QUERYEMPTY',
+        15 => 'PORTAL_LA_SOAPFAILED',
+        16 => 'PORTAL_LA_SLOFAILED',
+        17 => 'PORTAL_LA_SSOFAILED',
+        18 => 'PORTAL_LA_SSOINITFAILED',
+        19 => 'PORTAL_LA_SESSIONERROR',
+        20 => 'PORTAL_LA_SEPFAILED',
         21 => 'PORTAL_PP_ACCOUNT_LOCKED',
         22 => 'PORTAL_PP_PASSWORD_EXPIRED',
-        23 => 'PORTAL_CERTIFICATEREQUIRED',
-        24 => 'PORTAL_ERROR',
-        25 => 'PORTAL_PP_CHANGE_AFTER_RESET',
-        26 => 'PORTAL_PP_PASSWORD_MOD_NOT_ALLOWED',
-        27 => 'PORTAL_PP_MUST_SUPPLY_OLD_PASSWORD',
-        28 => 'PORTAL_PP_INSUFFICIENT_PASSWORD_QUALITY',
-        29 => 'PORTAL_PP_PASSWORD_TOO_SHORT',
-        30 => 'PORTAL_PP_PASSWORD_TOO_YOUNG',
-        31 => 'PORTAL_PP_PASSWORD_IN_HISTORY',
-        32 => 'PORTAL_PP_GRACE',
-        33 => 'PORTAL_PP_EXP_WARNING',
-        34 => 'PORTAL_PASSWORD_MISMATCH',
-        35 => 'PORTAL_PASSWORD_OK',
-        36 => 'PORTAL_NOTIFICATION',
-        37 => 'PORTAL_BADURL',
-        38 => 'PORTAL_NOSCHEME',
-        39 => 'PORTAL_BADOLDPASSWORD',
-        40 => 'PORTAL_MALFORMEDUSER',
-        41 => 'PORTAL_SESSIONNOTGRANTED',
-        42 => 'PORTAL_CONFIRM',
-        43 => 'PORTAL_MAILFORMEMPTY',
-        44 => 'PORTAL_BADMAILTOKEN',
-        45 => 'PORTAL_MAILERROR',
-        46 => 'PORTAL_MAILOK',
-        47 => 'PORTAL_LOGOUT_OK',
     };
 }
 
@@ -71,11 +46,6 @@ eval {
     POSIX::setuid( ( getpwnam( $ENV{APACHE_RUN_USER} ) )[2] );
 };
 
-## @rfn void run(string localStorage, hashRef localStorageOptions)
-# Main.
-# Reads requests from STDIN to :
-# - update counts
-# - display results
 sub run {
     my ( $localStorage, $localStorageOptions ) = ( shift, shift );
     my $refLocalStorage;
@@ -97,10 +67,7 @@ sub run {
         $lastMn = $mn;
 
         # Activity collect
-        if (
-/^(\S+)\s+=>\s+(\S+)\s+(OK|REJECT|REDIRECT|LOGOUT|UNPROTECT|\-?\d+)$/
-          )
-        {
+        if (/^(\S+)\s+=>\s+(\S+)\s+(OK|REJECT|REDIRECT|LOGOUT|\-?\d+)$/) {
             my ( $user, $uri, $code ) = ( $1, $2, $3 );
 
             # Portal error translation
@@ -134,6 +101,7 @@ sub run {
             %$args = split( /[=&]/, $tmp ) if ($tmp);
             &head;
 
+            #print Dumper($args),&end;next;
             my ( $c, $m, $u );
             while ( my ( $user, $v ) = each( %{ $status->{user} } ) ) {
                 $u++ unless ( $user =~ /^\d+\.\d+\.\d+\.\d+$/ );
@@ -151,102 +119,86 @@ sub run {
                 $m->{$_} = sprintf( "%.2f", $m->{$_} / MN_COUNT );
                 $m->{$_} = int( $m->{$_} ) if ( $m->{$_} > 99 );
             }
-
-            # Raw values (Dump)
             if ( $args->{'dump'} ) {
                 print "<div id=\"dump\"><pre>\n";
                 print Dumper( $status, $activity, $count );
                 print "</pre></div>\n";
-                &end;
             }
-            else {
 
-                # Total requests
-                print "<h2>Total</h2>\n<div id=\"total\"><pre>\n";
-                print sprintf( "%-30s : \%6d (%.02f / mn)\n",
-                    $_, $c->{$_}, $c->{$_} / $mn )
-                  foreach ( sort keys %$c );
-                print "\n</pre></div>\n";
+            # Total requests
+            print "<h2>Total</h2>\n<div id=\"total\"><pre>\n";
+            print sprintf( "%-30s : \%6d (%.02f / mn)\n",
+                $_, $c->{$_}, $c->{$_} / $mn )
+              foreach ( sort keys %$c );
+            print "\n</pre></div>\n";
 
-                # Average
-                print "<h2>Average for last " . MN_COUNT
-                  . " minutes</h2>\n<div id=\"average\"><pre>\n";
-                print sprintf( "%-30s : %6s / mn\n", $_, $m->{$_} )
-                  foreach ( sort keys %$m );
-                print "\n</pre></div>\n";
+            # Average
+            print "<h2>Average for last " . MN_COUNT
+              . " minutes</h2>\n<div id=\"average\"><pre>\n";
+            print sprintf( "%-30s : %6s / mn\n", $_, $m->{$_} )
+              foreach ( sort keys %$m );
+            print "\n</pre></div>\n";
 
-                # Users connected
-                print "<div id=\"users\"><p>\nTotal users : $u\n</p></div>\n";
+            # Users connected
+            print "<div id=\"users\"><p>\nTotal users : $u\n</p></div>\n";
 
-                # Local cache
-                my @t =
-                  $refLocalStorage->get_keys(
-                    $localStorageOptions->{namespace} );
-                print "<div id=\"cache\"><p>\nLocal Cache : " . @t
-                  . " objects\n</p></div>\n";
+            # Local cache
+            my @t =
+              $refLocalStorage->get_keys( $localStorageOptions->{namespace} );
+            print "<div id=\"cache\"><p>\nLocal Cache : " . @t
+              . " objects\n</p></div>\n";
 
-                # Uptime
-                print "<div id=\"up\"><p>\nServer up for : "
-                  . &timeUp($mn)
-                  . "\n</p></div>\n";
+            # Top uri
+            if ( $args->{top} ) {
+                print "<hr/>\n";
+                $args->{categories} ||= 'REJECT,PORTAL_FIRSTACCESS,LOGOUT,OK';
 
-                # Top uri
-                if ( $args->{top} ) {
-                    print "<hr/>\n";
-                    $args->{categories} ||=
-                      'REJECT,PORTAL_FIRSTACCESS,LOGOUT,OK';
-
-                    # Vhost activity
-                    print
-"<h2>Virtual Host activity</h2>\n<div id=\"vhost\"><pre>\n";
-                    foreach (
-                        sort { $count->{vhost}->{$b} <=> $count->{vhost}->{$a} }
-                        keys %{ $count->{vhost} }
-                      )
-                    {
-                        print
-                          sprintf( "%-40s : %6d\n", $_, $count->{vhost}->{$_} );
-                    }
-                    print "\n</pre></div>\n";
-
-                    # General
-                    print "<h2>Top used URI</h2>\n<div id=\"uri\"><pre>\n";
-                    my $i = 0;
-                    foreach (
-                        sort { $count->{uri}->{$b} <=> $count->{uri}->{$a} }
-                        keys %{ $count->{uri} }
-                      )
-                    {
-                        last if ( $i == $args->{top} );
-                        last unless ( $count->{uri}->{$_} );
-                        $i++;
-                        print
-                          sprintf( "%-80s : %6d\n", $_, $count->{uri}->{$_} );
-                    }
-                    print "\n</pre></div>\n";
-
-                    # Top by category
-                    print
-"<table class=\"topByCat\"><tr><th style=\"width:20%\">Code</th><th>Top</th></tr>\n";
-                    foreach my $cat ( split /,/, $args->{categories} ) {
-                        print
-                          "<tr><td>$cat</td><td nowrap>\n<div id=\"$cat\">\n";
-                        topByCat( $cat, $args->{top} );
-                        print "</div>\n</td></tr>";
-                    }
-                    print "</table>\n";
+                # Vhost activity
+                print
+                  "<h2>Virtual Host activity</h2>\n<div id=\"vhost\"><pre>\n";
+                foreach (
+                    sort { $count->{vhost}->{$b} <=> $count->{vhost}->{$a} }
+                    keys %{ $count->{vhost} }
+                  )
+                {
+                    print sprintf( "%-40s : %6d\n", $_, $count->{vhost}->{$_} );
                 }
+                print "\n</pre></div>\n";
 
-                &end;
+                # General
+                print "<h2>Top used URI</h2>\n<div id=\"uri\"><pre>\n";
+                my $i = 0;
+                foreach (
+                    sort { $count->{uri}->{$b} <=> $count->{uri}->{$a} }
+                    keys %{ $count->{uri} }
+                  )
+                {
+                    last if ( $i == $args->{top} );
+                    last unless ( $count->{uri}->{$_} );
+                    $i++;
+                    print sprintf( "%-80s : %6d\n", $_, $count->{uri}->{$_} );
+                }
+                print "\n</pre></div>\n";
+
+                # Top by category
+                print
+"<table border=\"1\" width=\"100%\"><tr><th>Code</th><th>Top</ht></tr>\n";
+                foreach my $cat ( split /,/, $args->{categories} ) {
+                    print
+"<tr><td><pre>$cat</pre></td><td nowrap>\n<div id=\"$cat\">\n";
+                    topByCat( $cat, $args->{top} );
+                    print "</div>\n</td></tr>";
+                }
+                print "</table>\n";
             }
+            print "<div id=\"up\"><p>\nServer up for : "
+              . &timeUp($mn)
+              . "\n</p></div>\n";
+            &end;
         }
     }
 }
 
-## @rfn private string timeUp(int d)
-# Return the time since the status process was launched (last Apache reload).
-# @param $d Number of minutes since start
-# @return Date in format "day hour minute"
 sub timeUp {
     my $d  = shift;
     my $mn = $d % 60;
@@ -256,12 +208,8 @@ sub timeUp {
     return "$d\d $h\h $mn\mn";
 }
 
-## @rfn private void topByCat(string cat,int max)
-# Display the "top 10" for a category (OK, REDIRECT,...).
-# @param $cat Category to display
-# @param $max Number of lines to display
 sub topByCat {
-    my ( $cat, $max ) = splice @_;
+    my ( $cat, $max ) = @_;
     my $i = 0;
     print "<pre>\n";
     foreach (
@@ -277,8 +225,6 @@ sub topByCat {
     print "</pre>\n";
 }
 
-## @rfn private void head()
-# Display head of HTML status responses.
 sub head {
     print <<"EOF";
 <!DOCTYPE html
@@ -286,108 +232,34 @@ sub head {
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" lang="en-US" xml:lang="en-US">
 <head>
-<title>$page_title</title>
-<style type="text/css">
-<!--
-body{
-	background: #000;
-	color:#fff;
-	padding:10px 50px;
-	font-family:sans-serif;
-}
-h1 {
-	margin:5px 20px;
-}
-h2 {
-	margin:30px 0 0 0;
-	padding:0 10px;
-	border-left:20px solid orange;
-	line-height:20px;
-}
-hr {
-	height:1px;
-	background-color:orange;
-	margin:10px 0;
-	border:0;
-}
-a {
-	color:orange;
-	text-decoration:none;
-	font-weight:bold;
-}
-#footer {
-	text-align:center;
-}
-#footer a {
-	margin-left:10px;
-	padding:5px;
-	border-bottom:1px solid #fff;
-}
-#footer a:hover {
-	border-color:orange;
-}
-table.topByCat {
-	table-layout:fixed;
-	border-collapse:collapse;
-	border:1px solid #fff;
-	width:100%;
-}
-table.topByCat td, table.topByCat th {
-	padding:5px;
-	border:1px solid #fff;
-}
-table.topByCat th {
-	color:orange;
-	text-align:center;
-}
--->
-</style>
+<title>Lemonldap::NG Status</title>
 <meta http-equiv="Content-Type" content="text/html; charset=utf8" />
 </head>
 <body>
-<table>
-<tr>
-<td style="width:30px;height:30px;background:orange;">&nbsp;</td>
-<td>&nbsp;</td>
-<td rowspan=2><h1>$page_title</h1></td>
-</tr>
-</tr>
-<td>&nbsp;</td>
-<td style="width:30px;height:30px;background:orange;">&nbsp;</td>
-</tr>
-</table>
+<h1>Lemonldap::NG Status</h1>
 EOF
 }
 
-## @rfn private void end()
-# Display end of HTML status responses.
 sub end {
     print <<"EOF";
 <hr/>
-<div id="footer">
 <script type="text/javascript" language="Javascript">
   //<!--
   var a = document.location.href;
   a=a.replace(/\\?.*\$/,'');
-  document.write('<a href="'+a+'">Standard view</a>');
   document.write('<a href="'+a+'?top=10&categories=REJECT,PORTAL_FIRSTACCESS,LOGOUT,OK">Top 10</a>');
-  document.write('<a href="'+a+'?dump=1">Raw results</a>');
   //-->
 </script>
-</div>
 </body>
 </html>
 END
 EOF
 }
-
 1;
 __END__
 
 =head1 NAME
 
-=encoding utf8
-
 Lemonldap::NG::Handler::Status - Perl extension to add a mod_status like system for L<Lemonldap::NG::Handler>
 
 =head1 SYNOPSIS
@@ -413,7 +285,7 @@ Create your own package (example using a central configuration database):
         dbiUser             => "lemonldap",
         dbiPassword          => "password",
     }
-    # ... See Lemonldap::NG::Handler
+    # ... See Lemonldap::N::Handler
   } );
 
 =head2 Configure Apache
@@ -446,7 +318,7 @@ L<http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+Xavier Guimard, E<lt>guimard@E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
